Welcome to Pyobjus
==================

Pyobjus is a Python library for accessing Objective-C class. If you want to
access Java class, look at `Pyjnius
<http://pyjnius.readthedocs.org/en/latest/>`_.

This documentation is divided into differents parts. We recommend you to start
with :ref:`installation`, and then head over to the :ref:`quickstart`. If
you'd rather dive into the internals of Pyobjus, check out the :ref:`api`
documentation.
There are also nice examples of using classes from Foundation framework. These you can find on the :ref:`foundation_eg` page.

.. toctree::
   :maxdepth: 2

   installation
   quickstart
   pyobjus_internal
   core_tutorials
   foundation_eg
   pyobjus_ios
   api
   remarks

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

